@@ -10,7 +10,8 @@ public class LockedA3Test {
         A3Text3D a3_2 = new A3Text3D("LockedA3");
         a3_2.setLoc(-0.23,0.28,-1.0);
         a3_2.setScale(0.04);
-        a3_2.setLabel("label",5.0,0.0,0.0);
+        a3_2.setLabelLoc(5.0,0.0);
+        a3_2.setLabel("label");
         window.addLockedA3(a3_2);
     }
 }
