@@ -2,7 +2,7 @@ import jp.sourceforge.acerola3d.a3.*;
 import javax.swing.*;
 import java.awt.*;
 
-public class PaintTest implements Component2D {
+public class PaintTest extends Component2D {
     public void paint(Graphics2D g,A3CanvasInterface canvas) {
         g.setColor(Color.red);
         g.drawLine(0,0,100,100);
