@@ -2,6 +2,8 @@ package jp.sourceforge.acerola3d;
 
 import jp.sourceforge.acerola3d.a3.*;
 import java.net.*;
+import java.security.AccessController;
+import java.security.PrivilegedAction;
 
 /**
  * x-res:とx-rzip:プロトコルのURLを使うことができるように
@@ -27,6 +29,7 @@ public class A23 {
 //    public static final Serializable NULL = "NULL";
 
     A23() { ; }
+    static A23URLStreamHandlerFactory a23Factory;
 
     /**
      * URLを拡張してx-res:とx-rzip:プロトコルを使えるように
@@ -40,9 +43,14 @@ public class A23 {
                 System.out.println("A23.initA23(). A23URLStreamHandlerFactory is disabled.");
                 //System.exit(0);
             }
-            A23URLStreamHandlerFactory a23Factory = new A23URLStreamHandlerFactory();
+            a23Factory = new A23URLStreamHandlerFactory();
             try {
-                URL.setURLStreamHandlerFactory(a23Factory);
+                AccessController.doPrivilegedWithCombiner(new PrivilegedAction<Object>() {
+                    public Object run() {
+                        URL.setURLStreamHandlerFactory(a23Factory);
+                        return null;
+                    }
+                });
             } catch(Error e) {
                 //lg3dで使うような場合のためにこれを追加．
                 System.out.println("A23.initA23(). A23URLStreamHandlerFactory is disabled.");
