@@ -64,13 +64,13 @@ public class A3Arc extends A3Object {
             new LineArray(2,GeometryArray.COORDINATES | GeometryArray.COLOR_3);
         geometry.setCapability(GeometryArray.ALLOW_COORDINATE_WRITE);
 //      geometry.setCapability(GeometryArray.ALLOW_COLOR_WRITE);
-        if (this.getUpperDirection()==UpperDirection.Y) {
+        //if (this.getUpperDirection()==UpperDirection.Y) {
             vertex[0] = new Point3d(headX,headY,headZ);
             vertex[1] = new Point3d(tailX,tailY,tailZ);
-        } else if (this.getUpperDirection()==UpperDirection.Z){
-            vertex[0] = new Point3d(headX,headZ,-headY);
-            vertex[1] = new Point3d(tailX,tailZ,-tailY);
-        }
+        //} else if (this.getUpperDirection()==UpperDirection.Z){
+        //    vertex[0] = new Point3d(headX,headZ,-headY);
+        //    vertex[1] = new Point3d(tailX,tailZ,-tailY);
+        //}
         geometry.setCoordinates(0,vertex);
         geometry.setColor(0, new Color3f(java.awt.Color.blue));
         geometry.setColor(1, new Color3f(java.awt.Color.red));
@@ -128,13 +128,13 @@ public class A3Arc extends A3Object {
         repaint();
     }
     void repaint() {
-        if (this.getUpperDirection()==UpperDirection.Y) {
+        //if (this.getUpperDirection()==UpperDirection.Y) {
             vertex[0] = new Point3d(headX,headY,headZ);
             vertex[1] = new Point3d(tailX,tailY,tailZ);
-        } else if (this.getUpperDirection()==UpperDirection.Z){
-            vertex[0] = new Point3d(headX,headZ,-headY);
-            vertex[1] = new Point3d(tailX,tailZ,-tailY);
-        }
+        //} else if (this.getUpperDirection()==UpperDirection.Z){
+        //    vertex[0] = new Point3d(headX,headZ,-headY);
+        //    vertex[1] = new Point3d(tailX,tailZ,-tailY);
+        //}
         geometry.setCoordinates(0,vertex);
 //        geometry.setColor(0, new Color3f(java.awt.Color.blue));
 //        geometry.setColor(1, new Color3f(java.awt.Color.red));
