@@ -1,14 +1,14 @@
 package jp.sourceforge.acerola3d.a3;
 
 import javax.vecmath.*;
+
 import java.awt.*;
 
-class A3Label implements Component2D {
+class A3Label extends Component2D {
     A3Object a3;
     String label = "none";
     double offsetX;
     double offsetY;
-    double offsetZ;
     int width=0;
     int height=0;
     A3Label(String s,A3Object a3) {
@@ -17,15 +17,15 @@ class A3Label implements Component2D {
     }
     public void paint(Graphics2D g,A3CanvasInterface canvas) {
         Vector3d v = a3.getLoc();
-        Vector3d vv = new Vector3d(offsetX,offsetY,offsetZ);
+        if (!a3.lockedA3)
+            v = canvas.virtualCSToPhysicalCS(v);
+        Vector3d vv = new Vector3d(offsetX,offsetY,0.0);
         vv.scale(a3.getScale());
+        if (!a3.lockedA3)
+            vv.scale(1.0/canvas.getCameraScale());
         Vector3d p3d = new Vector3d(v.x+vv.x,v.y+vv.y,v.z+vv.z);
-        Point p = null;
-        if (a3.lockedA3==false) {
-            p = canvas.virtualCSToCanvas(new Point3d(p3d));
-        } else {
-            p = canvas.physicalCSToCanvas(new Point3d(p3d));
-        }
+        Point p = canvas.physicalCSToCanvas(new Point3d(p3d));
+
         if ((width==0)||(height==0)) {
             FontMetrics fm = g.getFontMetrics();
             width = fm.stringWidth(label)+4;
@@ -38,9 +38,12 @@ class A3Label implements Component2D {
     public void setString(String s) {
         label = s;
     }
-    public void setOffset(double x,double y,double z) {
+    public void setOffset(double x,double y) {
         offsetX = x;
         offsetY = y;
-        offsetZ = z;
+    }
+    public void calPhysicalZ(A3CanvasInterface canvas) {
+        Vector3d v = canvas.virtualCSToPhysicalCS(a3.getLoc());
+        z = v.z;
     }
 }
