@@ -27,8 +27,12 @@ public abstract class A3Object {
     /**
      * 座標系の上を指定するための列挙型。
      */
-    public enum UpperDirection {X,Y,Z}
-    UpperDirection upperDirection = UpperDirection.Y;
+    public enum UpperDirection {Y,Z}
+    Vector3d upperVector = new Vector3d(0.0,1.0,0.0);
+    /**
+     * 吹き出しの位置を指定するための列挙型。
+     */
+    public enum BalloonDir {RIGHT,LEFT,TOP,BOTTOM}
 
     /**
      * A3InitDataのデータをもとにしてA3Objectのインスタンスを
@@ -51,7 +55,7 @@ public abstract class A3Object {
             setLabel(d.label);
         if (d.balloon!=null)
             setBalloon(d.balloon);
-        upperDirection = d.upperDirection;
+        upperVector = d.upperVector;
         pickable = d.pickable;
     }
 
@@ -84,14 +88,23 @@ public abstract class A3Object {
     }
 
     /**
-     * 座標系の上方向を取得します。この座標の上方向とは、
-     * 3D空間に配置する再にどちらを上として配置するかの指定と、
-     * Action3DのAutoActionControl機能における正面の計算で、
+     * このオブジェクトの上方向を設定します。この上方向とは、
+     * A3Objectのオートコントロール機能における正面の計算で、
      * 必要になる上方向ベクトルとして使用されます。
      * デフォルトの上方向はY軸の正の方向です。
      */
-    public UpperDirection getUpperDirection() {
-        return upperDirection;
+    public void setUpperVector(Vector3d v) {
+        upperVector.set(v);
+    }
+
+    /**
+     * このオブジェクトの上方向を取得します。この上方向とは、
+     * A3Objectのオートコントロール機能における正面の計算で、
+     * 必要になる上方向ベクトルとして使用されます。
+     * デフォルトの上方向はY軸の正の方向です。
+     */
+    public Vector3d getUpperVector() {
+        return new Vector3d(upperVector);
     }
 
     /**
@@ -101,16 +114,17 @@ public abstract class A3Object {
      * 初期化するというのが、このメソッドの主な用途になります。
      */
     protected void setNode(Node n) {
-        if (this.getUpperDirection()==UpperDirection.Z) {
-            Transform3D tt = new Transform3D();
-//          tt.set(new Quat4d(1.0,0.0,0.0,0.0));
-            tt.set(new AxisAngle4d(1.0,0.0,0.0,Math.PI/2.0));
-            TransformGroup tg = new TransformGroup(tt);
-            tg.addChild(n);
-            behavior.setNode(tg);
-        } else {
-            behavior.setNode(n);
-        }
+//        if (this.getUpperDirection()==UpperDirection.Z) {
+//            Transform3D tt = new Transform3D();
+////          tt.set(new Quat4d(1.0,0.0,0.0,0.0));
+//            tt.set(new AxisAngle4d(1.0,0.0,0.0,Math.PI/2.0));
+//            TransformGroup tg = new TransformGroup(tt);
+//            tg.addChild(n);
+//            behavior.setNode(tg);
+//        } else {
+//            behavior.setNode(n);
+//        }
+        behavior.setNode(n);
     }
 
     /**
@@ -372,7 +386,7 @@ public abstract class A3Object {
     /**
      * このオブジェクトのリソースを開放します。
      */
-    public final void dispose() {
+    public void dispose() {
         if (scene!=null) {
             if (label!=null)
                 scene.del(label);
@@ -388,99 +402,61 @@ public abstract class A3Object {
      * ファイル名のような感じで)表示されているラベルを
      * 消去したい場合には，引数にnullをわたして下さい．
      */
-    public final void setLabel(String l) {
+    public void setLabel(String l) {
+        if (label==null)
+            label = new A3Label(l,this);
         if (l!=null) {
-            if (label!=null) {
-                label.setString(l);
-                if (scene!=null)
-                    scene.add(label);
-            } else {
-                label = new A3Label(l,this);
-                if (scene!=null)
-                    scene.add(label);
-            }
+            label.setString(l);
+            if (scene!=null)
+                scene.add(label);
         } else {
-            if (label!=null) {
-                if (scene!=null)
-                    scene.del(label);
-            }
+            if (scene!=null)
+                scene.del(label);
         }
     }
 
     /**
-     * 位置を指定してラベルをセットします。(デスクトップのアイコンの
-     * ファイル名のような感じで)
-     * 表示されているラベルを消去したい場合には，
-     * 引数lにnullをわたして下さい．
+     * ラベルを表示する場合のオフセットを設定します。
      */
-    public final void setLabel(String l,double x,double y,double z) {
-        if (l!=null) {
-            if (label!=null) {
-                label.setString(l);
-                label.setOffset(x,y,z);
-                if (scene!=null)
-                    scene.add(label);
-            } else {
-                label = new A3Label(l,this);
-                label.setOffset(x,y,z);
-                if (scene!=null)
-                    scene.add(label);
-            }
-        } else {
-            if (label!=null) {
-                if (scene!=null)
-                    scene.del(label);
-            }
-        }
+    public void setLabelLoc(double x,double y) {
+        if (label==null)
+            label = new A3Label("",this);
+        label.setOffset(x,y);
     }
 
     /**
      * 吹き出しをセットします。表示されている吹き出しを
      * 消去したい場合には，引数にnullをわたして下さい．
      */
-    public final void setBalloon(String s) {
+    public void setBalloon(String s) {
+        if (balloon==null)
+            balloon = new A3Balloon(s,this);
         if (s!=null) {
-            if (balloon!=null) {
-                balloon.setString(s);
-                if (scene!=null)
-                    scene.add(balloon);
-            } else {
-                balloon = new A3Balloon(s,this);
-                if (scene!=null)
-                    scene.add(balloon);
-            }
+            balloon.setString(s);
+            if (scene!=null)
+                scene.add(balloon);
         } else {
-            if (balloon!=null) {
-                if (scene!=null)
-                    scene.del(balloon);
-            }
+            if (scene!=null)
+                scene.del(balloon);
         }
     }
 
     /**
-     * 位置を指定して吹き出しをセットします。
-     * 表示されている吹き出しを消去したい場合には，
-     * 引数sにnullをわたして下さい．
+     * 吹き出しを表示する場合の向きとオフセットを設定します。
      */
-    public final void setBalloon(String s,double x,double y,double z) {
-        if (s!=null) {
-            if (balloon!=null) {
-                balloon.setString(s);
-                balloon.setOffset(x,y,z);
-                if (scene!=null)
-                    scene.add(balloon);
-            } else {
-                balloon = new A3Balloon(s,this);
-                balloon.setOffset(x,y,z);
-                if (scene!=null)
-                    scene.add(balloon);
-            }
-        } else {
-            if (balloon!=null) {
-                if (scene!=null)
-                    scene.del(balloon);
-            }
-        }
+    public void setBalloonLoc(BalloonDir d,double x,double y) {
+        if (balloon==null)
+            balloon = new A3Balloon("",this);
+        balloon.setOffset(d,x,y);
+    }
+
+    /**
+     * 吹き出しを表示する場合の向きを設定します。
+     */
+    public void setBalloonDir(BalloonDir d) {
+        if (balloon==null)
+            balloon = new A3Balloon("",this);
+        balloon.setDir(d);
     }
 
     /**
@@ -489,15 +465,11 @@ public abstract class A3Object {
      */
     public final void setSelected(boolean b) {
         isSelected = b;
+        if (selected==null)
+            selected =new A3Selected(this);
         if (b) {
-            if (selected!=null) {
-                if (scene!=null)
-                    scene.add(selected);
-            } else {
-                selected =new A3Selected(this);
-                if (scene!=null)
-                    scene.add(selected);
-            }
+            if (scene!=null)
+                scene.add(selected);
         } else {
             if (scene!=null)
                 scene.del(selected);
