@@ -9,6 +9,8 @@ import java.util.*;
 
 import java.lang.reflect.Constructor;
 import jp.sourceforge.acerola3d.a3.A3CanvasInterface.NaviMode;
+import java.security.AccessController;
+import java.security.PrivilegedAction;
 
 /**
  * A3CanvasとJA3Canvasの両方で共通して使うことが
@@ -104,7 +106,13 @@ class A3VirtualUniverse extends VirtualUniverse {
         locale.addBranchGraph(rootGroup);
 
         AudioDevice mixer = null;
-        String mixerClassName = System.getProperty("j3d.audiodevice");
+        String mixerClassName = 
+        AccessController.doPrivilegedWithCombiner(new PrivilegedAction<String>() {
+            public String run() {
+                return System.getProperty("j3d.audiodevice");
+            }
+        });
+
         System.out.println(mixerClassName);
         if (mixerClassName!=null) {
             try {
@@ -144,7 +152,11 @@ class A3VirtualUniverse extends VirtualUniverse {
         } else {
             System.out.println(mixer.getClass().getName());
             environment.setAudioDevice(mixer);
-            mixer.initialize();
+            try {
+                mixer.initialize();
+            } catch(Exception e) {
+                e.printStackTrace();
+            }
         }
 
         scene = new Scene(this,0);
@@ -514,7 +526,9 @@ class A3VirtualUniverse extends VirtualUniverse {
      * 仮想空間の座標系で表したベクトルを返します。
      */
     public Vector3d getCameraUnitVecX() {
-        return physicalCSToVirtualCS(new Vector3d(1.0,0.0,0.0));
+        Vector3d v = physicalCSToVirtualCS(new Vector3d(1.0,0.0,0.0));
+        v.sub(scene.cameraNowV);
+        return v;
     }
 
     /**
@@ -522,7 +536,9 @@ class A3VirtualUniverse extends VirtualUniverse {
      * 仮想空間の座標系で表したベクトルを返します。
      */
     public Vector3d getCameraUnitVecY() {
-        return physicalCSToVirtualCS(new Vector3d(0.0,1.0,0.0));
+        Vector3d v = physicalCSToVirtualCS(new Vector3d(0.0,1.0,0.0));
+        v.sub(scene.cameraNowV);
+        return v;
     }
 
     /**
@@ -530,7 +546,9 @@ class A3VirtualUniverse extends VirtualUniverse {
      * 仮想空間の座標系で表したベクトルを返します。
      */
     public Vector3d getCameraUnitVecZ() {
-        return physicalCSToVirtualCS(new Vector3d(0.0,0.0,1.0));
+        Vector3d v = physicalCSToVirtualCS(new Vector3d(0.0,0.0,1.0));
+        v.sub(scene.cameraNowV);
+        return v;
     }
 
     /**
