@@ -5,6 +5,7 @@ import javax.media.j3d.*;
 import javax.vecmath.*;
 import javax.swing.*;
 import java.awt.*;
+import java.awt.event.KeyListener;
 import java.awt.image.BufferedImage;
 import java.io.File;
 import java.io.IOException;
@@ -346,8 +347,7 @@ public class A3Widget extends JFrame implements A3CanvasInterface {
 
     /**
      * ナビゲーションの大まかなスピードを設定します。
-     * A3Controllerの作成者はこのスピードを参照して
-     * ナビゲーションのスピードを計算することが望まれます．
+     * 単位はm/s。デフォルト値は1.0。
      */
     public void setNavigationSpeed(double s) {
         universe.setNavigationSpeed(s);
@@ -355,6 +355,9 @@ public class A3Widget extends JFrame implements A3CanvasInterface {
 
     /**
      * ナビゲーションの大まかなスピードを取得します。
+     * 単位はm/s。A3Controllerの作成者はこの値を参照して
+     * ナビゲーションのスピードを
+     * 計算することが望まれます。
      */
     public double getNavigationSpeed() {
         return universe.getNavigationSpeed();
@@ -810,6 +813,24 @@ public class A3Widget extends JFrame implements A3CanvasInterface {
     public A3Object getAvatar(int scene) {
         return universe.getAvatar(scene);
     }
+//  ---------- KeyListener関係 ----------
+    /**
+     * KeyListenerを登録します。実際にはこのA3WidgetのKeyListenerを
+     * 登録するのではなく、このA3Widget内部で使用しているTransCanvas3Dに登録
+     * するようにオーバーライドしています。
+     */
+    public void addKeyListener(KeyListener l) {
+        tCanvas.addKeyListener(l);
+    }
+    /**
+     * 指定されたKeyListenerの登録を抹消します。実際にはこのA3Widgetの
+     * KeyListenerの登録を抹消するのではなく、このA3Widget内部で使用している
+     * TransCanvas3Dのに登録されているKeyListenerを抹消するようにオーバーライド
+     * しています。
+     */
+    public void removeKeyListener(KeyListener l) {
+        tCanvas.removeKeyListener(l);
+    }
 //  ---------- LockedA3の処理 ----------
     /**
      * A3Objectを追加してカメラに対して固定した位置に
