@@ -42,7 +42,6 @@ public class Action3D extends A3Object implements ActionObject {
         A3InitData initData = new A3InitData("jp.sourceforge.acerola3d.a3.Action3D");
         initData.set(a3URL,-1);
         Action3D a3 = new Action3D(initData);
-        a3.change(0);
         return a3;
     }
 
@@ -409,48 +408,105 @@ public class Action3D extends A3Object implements ActionObject {
     }
 
     /**
-     * モーションデータをアクションに設定．
-     * まだ未実装．
+     * RDFの情報をStringで返します。
+     */
+    public String getRDF() {
+        return actionBehavior.getRDF();
+    }
+    /**
+     * タグの情報をStringの配列で返します。
+     */
+    public String[] getTags() {
+        return actionBehavior.getTags();
+    }
+    /**
+     * プロファイルのURI識別子の情報を
+     * Stringの配列で返します。
+     */
+    public String[] getProfiles() {
+        return actionBehavior.getProfiles();
+    }
+    /**
+     * サムネール画像のURLを配列で返します。
+     */
+    public URL[] getThumbnails() {
+        try {
+            String u[] = actionBehavior.getThumbnails();
+            if (u!=null) {
+                URL ret[] = new URL[u.length];
+                for (int i=0;i<u.length;i++)
+                    ret[i] = new URL(u[i]);
+                return ret;
+            } else {
+                return null;
+            }
+        } catch (Exception e) {
+            e.printStackTrace();
+            return null;
+        }
+    }
+    /**
+     * Acerola3Dファイルの中に保存されている
+     * HTMLファイルのURLを返します。
+     */
+    public URL getHTML() {
+        try {
+            String u = actionBehavior.getHTML();
+            if (u!=null)
+                return new URL(u);
+            else
+                return null;
+        } catch (Exception e) {
+            e.printStackTrace();
+            return null;
+        }
+    }
+
+    /**
+     * モーションデータをアクションに設定。
      */
     public void setMotion(int actionNo,Motion motion) {
         actionBehavior.setMotion(actionNo,motion);
     }
 
     /**
-     * モーションデータをアクションに設定．
-     * まだ未実装．
+     * モーションデータをアクションに設定。
      */
     public void setMotion(Serializable action,Motion motion) {
         actionBehavior.setMotion(action,motion);
     }
 
     /**
-     * Shapeをあるアクションのボーンに設定
-     * まだ未実装．
+     * Shapeをあるアクションのボーンに設定。
+     * このメソッドが上手く機能するためには、このAction3Dオブジェクトが
+     * まだA3CanvasInterfaceに追加されていないことと、引数で指定した
+     * boneNameがCATALOG.XMLできちんと指定されていることが必要。
      */
     public void setShape(int actionNo,String boneName,Node shape) {
         actionBehavior.setShape(actionNo,boneName,shape);
     }
 
     /**
-     * Shapeをあるアクションのボーンに設定
-     * まだ未実装．
+     * Shapeをあるアクションのボーンに設定。
+     * このメソッドが上手く機能するためには、このAction3Dオブジェクトが
+     * まだA3CanvasInterfaceに追加されていないことと、引数で指定した
+     * boneNameがCATALOG.XMLできちんと指定されていることが必要。
      */
     public void setShape(Serializable action,String boneName,Node shape) {
         actionBehavior.setShape(action,boneName,shape);
     }
 
     /**
-     * Soundをアクションに設定
-     * まだ未実装．
+     * Soundをアクションに設定。
+     * まだ未実装。
      */
     public void setSound(int actionNo,MediaContainer sound) {
         actionBehavior.setSound(actionNo,sound);
     }
 
     /**
-     * Soundをアクションに設定
-     * まだ未実装．
+     * Soundをアクションに設定。
+     * まだ未実装。
      */
     public void setSound(Serializable action,MediaContainer sound) {
         actionBehavior.setSound(action,sound);
@@ -477,7 +533,157 @@ public class Action3D extends A3Object implements ActionObject {
         try {
             action3DDataCash.remove(new URL(url));
         } catch (MalformedURLException e) {
-            ;
+            e.printStackTrace();
         }
     }
+//----------------------------------------
+    /**
+     * ラベルをセットします。(デスクトップのアイコンの
+     * ファイル名のような感じで)表示されているラベルを
+     * 消去したい場合には，引数にnullをわたして下さい．
+     */
+    public void setLabel(String l) {
+        if (label==null) {
+            label = new A3Label(l,this);
+            actionBehavior.resetLabelParameters();//ポイント
+        }
+        if (l!=null) {
+            label.setString(l);
+            if (scene!=null)
+                scene.add(label);
+        } else {
+            if (scene!=null)
+                scene.del(label);
+        }
+    }
+
+    /**
+     * ラベルを表示する場合のオフセットを設定します。
+     */
+    public void setLabelLoc(double x,double y) {
+        super.setLabelLoc(x,y);
+        actionBehavior.setLabelLoc(x,y);
+    }
+    /**
+     * アクションを指定してラベルを表示する場合のオフセットを設定します。
+     */
+    public void setLabelLoc(int actionNo,double x,double y) {
+        if (this.getActionNo()==actionNo)
+            super.setLabelLoc(x,y);
+        actionBehavior.setLabelLoc(actionNo,x,y);
+    }
+    /**
+     * アクションを指定してラベルを表示する場合のオフセットを設定します。
+     */
+    public void setLabelLoc(Serializable action,double x,double y) {
+        int actionNo;
+        if (action instanceof Integer) {
+            actionNo = ((Integer)action).intValue();
+        } else if (action instanceof String) {
+            actionNo = this.getActionNo((String)action);
+        } else {
+            return;
+        }
+        if (this.getActionNo()==actionNo)
+            super.setLabelLoc(x,y);
+        actionBehavior.setLabelLoc(actionNo,x,y);
+    }
+    /**
+     * 吹き出しをセットします。表示されている吹き出しを
+     * 消去したい場合には，引数にnullをわたして下さい．
+     */
+    public void setBalloon(String s) {
+        if (balloon==null) {
+            balloon = new A3Balloon(s,this);
+            actionBehavior.resetBalloonParameters();//ポイント
+        }
+        if (s!=null) {
+            balloon.setString(s);
+            if (scene!=null)
+                scene.add(balloon);
+        } else {
+            if (scene!=null)
+                scene.del(balloon);
+        }
+    }
+
+    /**
+     * 向きを指定して吹き出しを表示する場合のオフセットを設定します。
+     */
+    public void setBalloonLoc(A3Object.BalloonDir d,double x,double y) {
+        if (balloon==null) {
+            balloon = new A3Balloon("",this);
+            actionBehavior.resetBalloonParameters();
+        }
+        balloon.setOffset(d,x,y);
+        actionBehavior.setBalloonLoc(d,x,y);
+    }
+
+    /**
+     * アクションと向きを指定して吹き出しを表示する場合のオフセットを設定します。
+     */
+    public void setBalloonLoc(int actionNo,A3Object.BalloonDir d,double x,double y) {
+        if (this.getActionNo()==actionNo) {
+            if (balloon==null) {
+                balloon = new A3Balloon("",this);
+                actionBehavior.resetBalloonParameters();
+            }
+            balloon.setOffset(d,x,y);
+        }
+        actionBehavior.setBalloonLoc(actionNo,d,x,y);
+    }
+
+    /**
+     * アクションと向きを指定して吹き出しを表示する場合のオフセットを設定します。
+     */
+    public void setBalloonLoc(Serializable action,A3Object.BalloonDir d,double x,double y) {
+        int actionNo;
+        if (action instanceof Integer) {
+            actionNo = ((Integer)action).intValue();
+        } else if (action instanceof String) {
+            actionNo = this.getActionNo((String)action);
+        } else {
+            return;
+        }
+        setBalloonLoc(actionNo,d,x,y);
+    }
+
+    /**
+     * 吹き出しを表示する場合の向きを設定します。
+     */
+    public void setBalloonDir(BalloonDir d) {
+        if (balloon==null) {
+            balloon = new A3Balloon("",this);
+            actionBehavior.resetBalloonParameters();
+        }
+        balloon.setDir(d);
+        actionBehavior.setBalloonDir(d);
+    }
+    /**
+     * アクションを指定して吹き出しを表示する場合の向きを設定します。
+     */
+    public void setBalloonDir(int actionNo,BalloonDir d) {
+        if (this.getActionNo()==actionNo) {
+            if (balloon==null) {
+                balloon = new A3Balloon("",this);
+                actionBehavior.resetBalloonParameters();
+            }
+            balloon.setDir(d);
+        }
+        actionBehavior.setBalloonDir(actionNo,d);
+    }
+    /**
+     * アクションを指定して吹き出しを表示する場合の向きを設定します。
+     */
+    public void setBalloonDir(Serializable action,BalloonDir d) {
+        int actionNo;
+        if (action instanceof Integer) {
+            actionNo = ((Integer)action);
+        } else if (action instanceof String) {
+            actionNo = this.getActionNo((String)action);
+        } else {
+            return;
+        }
+        setBalloonDir(actionNo,d);
+    }
 }
