@@ -30,6 +30,8 @@ import jp.sourceforge.acerola3d.a3.bvh.*;
 
 import jp.sourceforge.acerola3d.a3.catalog.*;
 import javax.xml.bind.*;
+import java.security.AccessController;
+import java.security.PrivilegedAction;
 
 /**
  * ファイルから読み込んだデータを再利用可能な形で保存しておく
@@ -466,7 +468,16 @@ class Action3DData {
 
     void init(URL url) throws Exception {
         this.url = url;
-        loadCatalog();
+        AccessController.doPrivilegedWithCombiner(new PrivilegedAction<Object>() {
+            public Object run() {
+                try {
+                    loadCatalog();
+                } catch(Exception e) {
+                    e.printStackTrace();
+                }
+                return null;
+            }
+        });
         loadAllShapes();
         loadAllMotions();
         loadAllSounds();
