@@ -220,8 +220,9 @@ class ActionBehavior extends Behavior implements Cloneable {
                 tg.setTransform(t);
             }
 
-            //初めてS2状態になった時のサウンド再生
-            if ((newPlayStatus==S2)&&(playStatus!=S2)) {
+            //再生後初めてのサウンド再生
+            //((newPlayStatus==4)&&(playStatus==0))==trueのような場合も再生する
+            if ((newPlayStatus>=S2)&&(playStatus<=S2)) {
                 if (a3Data.actions[actionNo].sound!=null) {
                     //a3Data.actions[actionNo].sound.setEnable(false);
                     a3Data.actions[actionNo].sound.setEnable(true);
