@@ -18,7 +18,9 @@ public class ChaseController extends A3Controller implements Runnable {
     /**
      * アバタ後方5メートルから追跡するように
      * カメラを自動制御するコントローラを生成
-     * します。
+     * します。A23.setDefaultUpperDirection()などで
+     * Z軸が上になる座標系に設定している場合は正常に機能しない
+     * ので他のコンストラクタを使って下さい。
      */
     public ChaseController() {
         q = new Quat4d(0.0,1.0,0.0,0.0);
@@ -53,6 +55,45 @@ public class ChaseController extends A3Controller implements Runnable {
         this.s = s;
     }
 
+    /**
+     * アバタを追跡するようにカメラを自動制御する
+     * コントローラを生成します。引数は、アバタを原点とする座標系で、
+     * 注視点とカメラの位置と上方向ベクトルと拡大率。
+     */
+    public ChaseController(Vector3d lookAt,Vector3d camera,Vector3d up,double s) {
+        Vector3d upperVector = new Vector3d(up);
+        upperVector.normalize();
+        Vector3d front = new Vector3d();
+        front.sub(lookAt,camera);
+        front.normalize();
+        //特定のカメラの向きでm.get(quat)が
+        //うまくいかない。なんでなのかわからない。
+        //なので、強引だけど以下のif文を入れて対応。
+        if (Math.abs(front.x)<0.0001) {
+            front.x = 0.0001;
+            front.normalize();
+        }
+        double d = front.dot(upperVector);
+        Vector3d vTmp = new Vector3d(front);
+        vTmp.scale(d);
+        Vector3d top = new Vector3d(upperVector);
+        top.sub(vTmp);
+        top.normalize();
+        Vector3d right = new Vector3d();
+        right.cross(front,top);
+        Matrix4d m = new Matrix4d();
+        m.m00 = right.x; m.m01 = top.x; m.m02 = -front.x;
+        m.m10 = right.y; m.m11 = top.y; m.m12 = -front.y;
+        m.m20 = right.z; m.m21 = top.z; m.m22 = -front.z;
+        Quat4d quat = new Quat4d();
+        m.get(quat);
+        System.out.println(quat);
+        System.out.println(front);
+        this.q = quat;
+        this.v = new Vector3d(camera);
+        this.s = s;
+    }
+
     /**
      * 初期化処理をします。Acerola3Dパッケージの内部で
      * 使用されるメソッドなので直接呼び出さないで下さい。
