@@ -54,7 +54,7 @@ package jp.sourceforge.acerola3d.a3;
 
 import com.sun.j3d.exp.swing.impl.AutoOffScreenCanvas3D;
 
-import java.awt.AlphaComposite;
+import java.awt.AlphaComposite; //kenji
 import java.awt.Dimension;
 import java.awt.EventQueue;
 import java.awt.GraphicsConfigTemplate;
@@ -64,7 +64,7 @@ import java.awt.GraphicsEnvironment;
 import java.awt.Rectangle;
 import java.awt.image.BufferedImage;
 import java.lang.reflect.InvocationTargetException;
-import java.util.Arrays;
+import java.util.Arrays; //kenji
 
 import javax.media.j3d.Canvas3D;
 import javax.media.j3d.GraphicsConfigTemplate3D;
@@ -259,7 +259,13 @@ class TransCanvas3D extends JPanel implements AncestorListener {
 
         setOpaque(false);//kenji おれが追加．
     }
-
+    //kenji
+    public void addNotify() {
+        super.addNotify();
+        enableEvents(java.awt.AWTEvent.MOUSE_EVENT_MASK);
+        enableEvents(java.awt.AWTEvent.MOUSE_MOTION_EVENT_MASK);
+        enableEvents(java.awt.AWTEvent.MOUSE_WHEEL_EVENT_MASK);
+    }
     /**
      * {@inheritDoc}
      *
@@ -419,7 +425,7 @@ class TransCanvas3D extends JPanel implements AncestorListener {
         return resizeValidationDelay;
     }
 
-    float depthData[] = null;
+    float depthData[] = null; //kenji
     /**
      * Paints the result of the rendering. If the rendered buffer is
      * not useable (render thread being between [code]postRender()[/code] and
